..
      Copyright 2015 IBM
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Welcome to nova-powervm's documentation!
========================================

This project provides a Nova-compatible compute driver for `PowerVM`_ systems.

The project aims to integrate into OpenStack's Nova project.  Initial
development is occurring in a separate project until it has matured and met the
Nova core team's requirements.  As such, all development practices should
mirror those of the Nova project.

Documentation on Nova can be found at the `Nova Devref`_.

.. _`PowerVM`: http://www-03.ibm.com/systems/power/software/virtualization/
.. _`Nova Devref`: http://docs.openstack.org/developer/nova/devref

Nova-PowerVM Overview
=====================

Contents:

.. toctree::
    :maxdepth: 1

    readme

Nova-PowerVM Policies
=====================

Contents:

.. toctree::
   :maxdepth: 1

   policies/index

Nova-PowerVM Devref
===================

Contents:

.. toctree::
   :maxdepth: 1

   devref/index
